import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AndroidEnterpriseResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class DevicesResource(googleapiclient.discovery.Resource):
        def forceReportUpload(
            self, *, enterpriseId: str, userId: str, deviceId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, enterpriseId: str, userId: str, deviceId: str, **kwargs: typing.Any
        ) -> DeviceHttpRequest: ...
        def getState(
            self, *, enterpriseId: str, userId: str, deviceId: str, **kwargs: typing.Any
        ) -> DeviceStateHttpRequest: ...
        def list(
            self, *, enterpriseId: str, userId: str, **kwargs: typing.Any
        ) -> DevicesListResponseHttpRequest: ...
        def setState(
            self,
            *,
            enterpriseId: str,
            userId: str,
            deviceId: str,
            body: DeviceState = ...,
            **kwargs: typing.Any
        ) -> DeviceStateHttpRequest: ...
        def update(
            self,
            *,
            enterpriseId: str,
            userId: str,
            deviceId: str,
            body: Device = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> DeviceHttpRequest: ...

    @typing.type_check_only
    class EnterprisesResource(googleapiclient.discovery.Resource):
        def acknowledgeNotificationSet(
            self, *, notificationSetId: str = ..., **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def completeSignup(
            self,
            *,
            completionToken: str = ...,
            enterpriseToken: str = ...,
            **kwargs: typing.Any
        ) -> EnterpriseHttpRequest: ...
        def createWebToken(
            self,
            *,
            enterpriseId: str,
            body: AdministratorWebTokenSpec = ...,
            **kwargs: typing.Any
        ) -> AdministratorWebTokenHttpRequest: ...
        def enroll(
            self, *, token: str, body: Enterprise = ..., **kwargs: typing.Any
        ) -> EnterpriseHttpRequest: ...
        def generateSignupUrl(
            self, *, callbackUrl: str = ..., **kwargs: typing.Any
        ) -> SignupInfoHttpRequest: ...
        def get(
            self, *, enterpriseId: str, **kwargs: typing.Any
        ) -> EnterpriseHttpRequest: ...
        def getServiceAccount(
            self,
            *,
            enterpriseId: str,
            keyType: typing_extensions.Literal["googleCredentials", "pkcs12"] = ...,
            **kwargs: typing.Any
        ) -> ServiceAccountHttpRequest: ...
        def getStoreLayout(
            self, *, enterpriseId: str, **kwargs: typing.Any
        ) -> StoreLayoutHttpRequest: ...
        def list(
            self, *, domain: str, **kwargs: typing.Any
        ) -> EnterprisesListResponseHttpRequest: ...
        def pullNotificationSet(
            self,
            *,
            requestMode: typing_extensions.Literal[
                "waitForNotifications", "returnImmediately"
            ] = ...,
            **kwargs: typing.Any
        ) -> NotificationSetHttpRequest: ...
        def sendTestPushNotification(
            self, *, enterpriseId: str, **kwargs: typing.Any
        ) -> EnterprisesSendTestPushNotificationResponseHttpRequest: ...
        def setAccount(
            self,
            *,
            enterpriseId: str,
            body: EnterpriseAccount = ...,
            **kwargs: typing.Any
        ) -> EnterpriseAccountHttpRequest: ...
        def setStoreLayout(
            self, *, enterpriseId: str, body: StoreLayout = ..., **kwargs: typing.Any
        ) -> StoreLayoutHttpRequest: ...
        def unenroll(
            self, *, enterpriseId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class EntitlementsResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            enterpriseId: str,
            userId: str,
            entitlementId: str,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            enterpriseId: str,
            userId: str,
            entitlementId: str,
            **kwargs: typing.Any
        ) -> EntitlementHttpRequest: ...
        def list(
            self, *, enterpriseId: str, userId: str, **kwargs: typing.Any
        ) -> EntitlementsListResponseHttpRequest: ...
        def update(
            self,
            *,
            enterpriseId: str,
            userId: str,
            entitlementId: str,
            body: Entitlement = ...,
            install: bool = ...,
            **kwargs: typing.Any
        ) -> EntitlementHttpRequest: ...

    @typing.type_check_only
    class GrouplicensesResource(googleapiclient.discovery.Resource):
        def get(
            self, *, enterpriseId: str, groupLicenseId: str, **kwargs: typing.Any
        ) -> GroupLicenseHttpRequest: ...
        def list(
            self, *, enterpriseId: str, **kwargs: typing.Any
        ) -> GroupLicensesListResponseHttpRequest: ...

    @typing.type_check_only
    class GrouplicenseusersResource(googleapiclient.discovery.Resource):
        def list(
            self, *, enterpriseId: str, groupLicenseId: str, **kwargs: typing.Any
        ) -> GroupLicenseUsersListResponseHttpRequest: ...

    @typing.type_check_only
    class InstallsResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            enterpriseId: str,
            userId: str,
            deviceId: str,
            installId: str,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            enterpriseId: str,
            userId: str,
            deviceId: str,
            installId: str,
            **kwargs: typing.Any
        ) -> InstallHttpRequest: ...
        def list(
            self, *, enterpriseId: str, userId: str, deviceId: str, **kwargs: typing.Any
        ) -> InstallsListResponseHttpRequest: ...
        def update(
            self,
            *,
            enterpriseId: str,
            userId: str,
            deviceId: str,
            installId: str,
            body: Install = ...,
            **kwargs: typing.Any
        ) -> InstallHttpRequest: ...

    @typing.type_check_only
    class ManagedconfigurationsfordeviceResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            enterpriseId: str,
            userId: str,
            deviceId: str,
            managedConfigurationForDeviceId: str,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            enterpriseId: str,
            userId: str,
            deviceId: str,
            managedConfigurationForDeviceId: str,
            **kwargs: typing.Any
        ) -> ManagedConfigurationHttpRequest: ...
        def list(
            self, *, enterpriseId: str, userId: str, deviceId: str, **kwargs: typing.Any
        ) -> ManagedConfigurationsForDeviceListResponseHttpRequest: ...
        def update(
            self,
            *,
            enterpriseId: str,
            userId: str,
            deviceId: str,
            managedConfigurationForDeviceId: str,
            body: ManagedConfiguration = ...,
            **kwargs: typing.Any
        ) -> ManagedConfigurationHttpRequest: ...

    @typing.type_check_only
    class ManagedconfigurationsforuserResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            enterpriseId: str,
            userId: str,
            managedConfigurationForUserId: str,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            enterpriseId: str,
            userId: str,
            managedConfigurationForUserId: str,
            **kwargs: typing.Any
        ) -> ManagedConfigurationHttpRequest: ...
        def list(
            self, *, enterpriseId: str, userId: str, **kwargs: typing.Any
        ) -> ManagedConfigurationsForUserListResponseHttpRequest: ...
        def update(
            self,
            *,
            enterpriseId: str,
            userId: str,
            managedConfigurationForUserId: str,
            body: ManagedConfiguration = ...,
            **kwargs: typing.Any
        ) -> ManagedConfigurationHttpRequest: ...

    @typing.type_check_only
    class ManagedconfigurationssettingsResource(googleapiclient.discovery.Resource):
        def list(
            self, *, enterpriseId: str, productId: str, **kwargs: typing.Any
        ) -> ManagedConfigurationsSettingsListResponseHttpRequest: ...

    @typing.type_check_only
    class PermissionsResource(googleapiclient.discovery.Resource):
        def get(
            self, *, permissionId: str, language: str = ..., **kwargs: typing.Any
        ) -> PermissionHttpRequest: ...

    @typing.type_check_only
    class ProductsResource(googleapiclient.discovery.Resource):
        def approve(
            self,
            *,
            enterpriseId: str,
            productId: str,
            body: ProductsApproveRequest = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def generateApprovalUrl(
            self,
            *,
            enterpriseId: str,
            productId: str,
            languageCode: str = ...,
            **kwargs: typing.Any
        ) -> ProductsGenerateApprovalUrlResponseHttpRequest: ...
        def get(
            self,
            *,
            enterpriseId: str,
            productId: str,
            language: str = ...,
            **kwargs: typing.Any
        ) -> ProductHttpRequest: ...
        def getAppRestrictionsSchema(
            self,
            *,
            enterpriseId: str,
            productId: str,
            language: str = ...,
            **kwargs: typing.Any
        ) -> AppRestrictionsSchemaHttpRequest: ...
        def getPermissions(
            self, *, enterpriseId: str, productId: str, **kwargs: typing.Any
        ) -> ProductPermissionsHttpRequest: ...
        def list(
            self,
            *,
            enterpriseId: str,
            approved: bool = ...,
            language: str = ...,
            maxResults: int = ...,
            query: str = ...,
            token: str = ...,
            **kwargs: typing.Any
        ) -> ProductsListResponseHttpRequest: ...
        def unapprove(
            self, *, enterpriseId: str, productId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class ServiceaccountkeysResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, enterpriseId: str, keyId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def insert(
            self,
            *,
            enterpriseId: str,
            body: ServiceAccountKey = ...,
            **kwargs: typing.Any
        ) -> ServiceAccountKeyHttpRequest: ...
        def list(
            self, *, enterpriseId: str, **kwargs: typing.Any
        ) -> ServiceAccountKeysListResponseHttpRequest: ...

    @typing.type_check_only
    class StorelayoutclustersResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            enterpriseId: str,
            pageId: str,
            clusterId: str,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            enterpriseId: str,
            pageId: str,
            clusterId: str,
            **kwargs: typing.Any
        ) -> StoreClusterHttpRequest: ...
        def insert(
            self,
            *,
            enterpriseId: str,
            pageId: str,
            body: StoreCluster = ...,
            **kwargs: typing.Any
        ) -> StoreClusterHttpRequest: ...
        def list(
            self, *, enterpriseId: str, pageId: str, **kwargs: typing.Any
        ) -> StoreLayoutClustersListResponseHttpRequest: ...
        def update(
            self,
            *,
            enterpriseId: str,
            pageId: str,
            clusterId: str,
            body: StoreCluster = ...,
            **kwargs: typing.Any
        ) -> StoreClusterHttpRequest: ...

    @typing.type_check_only
    class StorelayoutpagesResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, enterpriseId: str, pageId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, enterpriseId: str, pageId: str, **kwargs: typing.Any
        ) -> StorePageHttpRequest: ...
        def insert(
            self, *, enterpriseId: str, body: StorePage = ..., **kwargs: typing.Any
        ) -> StorePageHttpRequest: ...
        def list(
            self, *, enterpriseId: str, **kwargs: typing.Any
        ) -> StoreLayoutPagesListResponseHttpRequest: ...
        def update(
            self,
            *,
            enterpriseId: str,
            pageId: str,
            body: StorePage = ...,
            **kwargs: typing.Any
        ) -> StorePageHttpRequest: ...

    @typing.type_check_only
    class UsersResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, enterpriseId: str, userId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def generateAuthenticationToken(
            self, *, enterpriseId: str, userId: str, **kwargs: typing.Any
        ) -> AuthenticationTokenHttpRequest: ...
        def get(
            self, *, enterpriseId: str, userId: str, **kwargs: typing.Any
        ) -> UserHttpRequest: ...
        def getAvailableProductSet(
            self, *, enterpriseId: str, userId: str, **kwargs: typing.Any
        ) -> ProductSetHttpRequest: ...
        def insert(
            self, *, enterpriseId: str, body: User = ..., **kwargs: typing.Any
        ) -> UserHttpRequest: ...
        def list(
            self, *, enterpriseId: str, email: str, **kwargs: typing.Any
        ) -> UsersListResponseHttpRequest: ...
        def revokeDeviceAccess(
            self, *, enterpriseId: str, userId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def setAvailableProductSet(
            self,
            *,
            enterpriseId: str,
            userId: str,
            body: ProductSet = ...,
            **kwargs: typing.Any
        ) -> ProductSetHttpRequest: ...
        def update(
            self,
            *,
            enterpriseId: str,
            userId: str,
            body: User = ...,
            **kwargs: typing.Any
        ) -> UserHttpRequest: ...

    @typing.type_check_only
    class WebappsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, enterpriseId: str, webAppId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, enterpriseId: str, webAppId: str, **kwargs: typing.Any
        ) -> WebAppHttpRequest: ...
        def insert(
            self, *, enterpriseId: str, body: WebApp = ..., **kwargs: typing.Any
        ) -> WebAppHttpRequest: ...
        def list(
            self, *, enterpriseId: str, **kwargs: typing.Any
        ) -> WebAppsListResponseHttpRequest: ...
        def update(
            self,
            *,
            enterpriseId: str,
            webAppId: str,
            body: WebApp = ...,
            **kwargs: typing.Any
        ) -> WebAppHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def devices(self) -> DevicesResource: ...
    def enterprises(self) -> EnterprisesResource: ...
    def entitlements(self) -> EntitlementsResource: ...
    def grouplicenses(self) -> GrouplicensesResource: ...
    def grouplicenseusers(self) -> GrouplicenseusersResource: ...
    def installs(self) -> InstallsResource: ...
    def managedconfigurationsfordevice(
        self,
    ) -> ManagedconfigurationsfordeviceResource: ...
    def managedconfigurationsforuser(self) -> ManagedconfigurationsforuserResource: ...
    def managedconfigurationssettings(
        self,
    ) -> ManagedconfigurationssettingsResource: ...
    def permissions(self) -> PermissionsResource: ...
    def products(self) -> ProductsResource: ...
    def serviceaccountkeys(self) -> ServiceaccountkeysResource: ...
    def storelayoutclusters(self) -> StorelayoutclustersResource: ...
    def storelayoutpages(self) -> StorelayoutpagesResource: ...
    def users(self) -> UsersResource: ...
    def webapps(self) -> WebappsResource: ...

@typing.type_check_only
class AdministratorWebTokenHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AdministratorWebToken: ...

@typing.type_check_only
class AppRestrictionsSchemaHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AppRestrictionsSchema: ...

@typing.type_check_only
class AuthenticationTokenHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AuthenticationToken: ...

@typing.type_check_only
class DeviceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Device: ...

@typing.type_check_only
class DeviceStateHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DeviceState: ...

@typing.type_check_only
class DevicesListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DevicesListResponse: ...

@typing.type_check_only
class EnterpriseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Enterprise: ...

@typing.type_check_only
class EnterpriseAccountHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EnterpriseAccount: ...

@typing.type_check_only
class EnterprisesListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EnterprisesListResponse: ...

@typing.type_check_only
class EnterprisesSendTestPushNotificationResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EnterprisesSendTestPushNotificationResponse: ...

@typing.type_check_only
class EntitlementHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Entitlement: ...

@typing.type_check_only
class EntitlementsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EntitlementsListResponse: ...

@typing.type_check_only
class GroupLicenseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GroupLicense: ...

@typing.type_check_only
class GroupLicenseUsersListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GroupLicenseUsersListResponse: ...

@typing.type_check_only
class GroupLicensesListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GroupLicensesListResponse: ...

@typing.type_check_only
class InstallHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Install: ...

@typing.type_check_only
class InstallsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> InstallsListResponse: ...

@typing.type_check_only
class ManagedConfigurationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ManagedConfiguration: ...

@typing.type_check_only
class ManagedConfigurationsForDeviceListResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ManagedConfigurationsForDeviceListResponse: ...

@typing.type_check_only
class ManagedConfigurationsForUserListResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ManagedConfigurationsForUserListResponse: ...

@typing.type_check_only
class ManagedConfigurationsSettingsListResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ManagedConfigurationsSettingsListResponse: ...

@typing.type_check_only
class NotificationSetHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> NotificationSet: ...

@typing.type_check_only
class PermissionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Permission: ...

@typing.type_check_only
class ProductHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Product: ...

@typing.type_check_only
class ProductPermissionsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ProductPermissions: ...

@typing.type_check_only
class ProductSetHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ProductSet: ...

@typing.type_check_only
class ProductsGenerateApprovalUrlResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ProductsGenerateApprovalUrlResponse: ...

@typing.type_check_only
class ProductsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ProductsListResponse: ...

@typing.type_check_only
class ServiceAccountHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ServiceAccount: ...

@typing.type_check_only
class ServiceAccountKeyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ServiceAccountKey: ...

@typing.type_check_only
class ServiceAccountKeysListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ServiceAccountKeysListResponse: ...

@typing.type_check_only
class SignupInfoHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SignupInfo: ...

@typing.type_check_only
class StoreClusterHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> StoreCluster: ...

@typing.type_check_only
class StoreLayoutHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> StoreLayout: ...

@typing.type_check_only
class StoreLayoutClustersListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> StoreLayoutClustersListResponse: ...

@typing.type_check_only
class StoreLayoutPagesListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> StoreLayoutPagesListResponse: ...

@typing.type_check_only
class StorePageHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> StorePage: ...

@typing.type_check_only
class UserHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> User: ...

@typing.type_check_only
class UsersListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UsersListResponse: ...

@typing.type_check_only
class WebAppHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WebApp: ...

@typing.type_check_only
class WebAppsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WebAppsListResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AppengineResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AppsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            def get(
                self, *, appsId: str, locationsId: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                appsId: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...

        @typing.type_check_only
        class OperationsResource(googleapiclient.discovery.Resource):
            def get(
                self, *, appsId: str, operationsId: str, **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def list(
                self,
                *,
                appsId: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListOperationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListOperationsResponseHttpRequest,
                previous_response: ListOperationsResponse,
            ) -> ListOperationsResponseHttpRequest | None: ...

        @typing.type_check_only
        class ServicesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class VersionsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class InstancesResource(googleapiclient.discovery.Resource):
                    def debug(
                        self,
                        *,
                        appsId: str,
                        servicesId: str,
                        versionsId: str,
                        instancesId: str,
                        body: DebugInstanceRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self,
                        *,
                        appsId: str,
                        servicesId: str,
                        versionsId: str,
                        instancesId: str,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def get(
                        self,
                        *,
                        appsId: str,
                        servicesId: str,
                        versionsId: str,
                        instancesId: str,
                        **kwargs: typing.Any
                    ) -> InstanceHttpRequest: ...
                    def list(
                        self,
                        *,
                        appsId: str,
                        servicesId: str,
                        versionsId: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListInstancesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListInstancesResponseHttpRequest,
                        previous_response: ListInstancesResponse,
                    ) -> ListInstancesResponseHttpRequest | None: ...

                def create(
                    self,
                    *,
                    appsId: str,
                    servicesId: str,
                    body: Version = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    appsId: str,
                    servicesId: str,
                    versionsId: str,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self,
                    *,
                    appsId: str,
                    servicesId: str,
                    versionsId: str,
                    view: typing_extensions.Literal["BASIC", "FULL"] = ...,
                    **kwargs: typing.Any
                ) -> VersionHttpRequest: ...
                def list(
                    self,
                    *,
                    appsId: str,
                    servicesId: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    view: typing_extensions.Literal["BASIC", "FULL"] = ...,
                    **kwargs: typing.Any
                ) -> ListVersionsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListVersionsResponseHttpRequest,
                    previous_response: ListVersionsResponse,
                ) -> ListVersionsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    appsId: str,
                    servicesId: str,
                    versionsId: str,
                    body: Version = ...,
                    mask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def instances(self) -> InstancesResource: ...

            def delete(
                self, *, appsId: str, servicesId: str, **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self, *, appsId: str, servicesId: str, **kwargs: typing.Any
            ) -> ServiceHttpRequest: ...
            def list(
                self,
                *,
                appsId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListServicesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListServicesResponseHttpRequest,
                previous_response: ListServicesResponse,
            ) -> ListServicesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                appsId: str,
                servicesId: str,
                body: Service = ...,
                mask: str = ...,
                migrateTraffic: bool = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def versions(self) -> VersionsResource: ...

        def create(
            self, *, body: Application = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(
            self, *, appsId: str, ensureResourcesExist: bool = ..., **kwargs: typing.Any
        ) -> ApplicationHttpRequest: ...
        def patch(
            self,
            *,
            appsId: str,
            body: Application = ...,
            mask: str = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def locations(self) -> LocationsResource: ...
        def operations(self) -> OperationsResource: ...
        def services(self) -> ServicesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def apps(self) -> AppsResource: ...

@typing.type_check_only
class ApplicationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Application: ...

@typing.type_check_only
class InstanceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Instance: ...

@typing.type_check_only
class ListInstancesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListInstancesResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListServicesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListServicesResponse: ...

@typing.type_check_only
class ListVersionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListVersionsResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class ServiceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Service: ...

@typing.type_check_only
class VersionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Version: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Bucket(typing_extensions.TypedDict, total=False):
    acl: _list[BucketAccessControl]
    autoclass: dict[str, typing.Any]
    billing: dict[str, typing.Any]
    cors: _list[dict[str, typing.Any]]
    customPlacementConfig: dict[str, typing.Any]
    defaultEventBasedHold: bool
    defaultObjectAcl: _list[ObjectAccessControl]
    encryption: dict[str, typing.Any]
    etag: str
    iamConfiguration: dict[str, typing.Any]
    id: str
    kind: str
    labels: dict[str, typing.Any]
    lifecycle: dict[str, typing.Any]
    location: str
    locationType: str
    logging: dict[str, typing.Any]
    metageneration: str
    name: str
    owner: dict[str, typing.Any]
    projectNumber: str
    retentionPolicy: dict[str, typing.Any]
    rpo: str
    satisfiesPZS: bool
    selfLink: str
    storageClass: str
    timeCreated: str
    updated: str
    versioning: dict[str, typing.Any]
    website: dict[str, typing.Any]

@typing.type_check_only
class BucketAccessControl(typing_extensions.TypedDict, total=False):
    bucket: str
    domain: str
    email: str
    entity: str
    entityId: str
    etag: str
    id: str
    kind: str
    projectTeam: dict[str, typing.Any]
    role: str
    selfLink: str

@typing.type_check_only
class BucketAccessControls(typing_extensions.TypedDict, total=False):
    items: _list[BucketAccessControl]
    kind: str

@typing.type_check_only
class Buckets(typing_extensions.TypedDict, total=False):
    items: _list[Bucket]
    kind: str
    nextPageToken: str

@typing.type_check_only
class Channel(typing_extensions.TypedDict, total=False):
    address: str
    expiration: str
    id: str
    kind: str
    params: dict[str, typing.Any]
    payload: bool
    resourceId: str
    resourceUri: str
    token: str
    type: str

@typing.type_check_only
class ComposeRequest(typing_extensions.TypedDict, total=False):
    destination: Object
    kind: str
    sourceObjects: _list[dict[str, typing.Any]]

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class HmacKey(typing_extensions.TypedDict, total=False):
    kind: str
    metadata: HmacKeyMetadata
    secret: str

@typing.type_check_only
class HmacKeyMetadata(typing_extensions.TypedDict, total=False):
    accessId: str
    etag: str
    id: str
    kind: str
    projectId: str
    selfLink: str
    serviceAccountEmail: str
    state: str
    timeCreated: str
    updated: str

@typing.type_check_only
class HmacKeysMetadata(typing_extensions.TypedDict, total=False):
    items: _list[HmacKeyMetadata]
    kind: str
    nextPageToken: str

@typing.type_check_only
class Notification(typing_extensions.TypedDict, total=False):
    custom_attributes: dict[str, typing.Any]
    etag: str
    event_types: _list[str]
    id: str
    kind: str
    object_name_prefix: str
    payload_format: str
    selfLink: str
    topic: str

@typing.type_check_only
class Notifications(typing_extensions.TypedDict, total=False):
    items: _list[Notification]
    kind: str

@typing.type_check_only
class Object(typing_extensions.TypedDict, total=False):
    acl: _list[ObjectAccessControl]
    bucket: str
    cacheControl: str
    componentCount: int
    contentDisposition: str
    contentEncoding: str
    contentLanguage: str
    contentType: str
    crc32c: str
    customTime: str
    customerEncryption: dict[str, typing.Any]
    etag: str
    eventBasedHold: bool
    generation: str
    id: str
    kind: str
    kmsKeyName: str
    md5Hash: str
    mediaLink: str
    metadata: dict[str, typing.Any]
    metageneration: str
    name: str
    owner: dict[str, typing.Any]
    retentionExpirationTime: str
    selfLink: str
    size: str
    storageClass: str
    temporaryHold: bool
    timeCreated: str
    timeDeleted: str
    timeStorageClassUpdated: str
    updated: str

@typing.type_check_only
class ObjectAccessControl(typing_extensions.TypedDict, total=False):
    bucket: str
    domain: str
    email: str
    entity: str
    entityId: str
    etag: str
    generation: str
    id: str
    kind: str
    object: str
    projectTeam: dict[str, typing.Any]
    role: str
    selfLink: str

@typing.type_check_only
class ObjectAccessControls(typing_extensions.TypedDict, total=False):
    items: _list[ObjectAccessControl]
    kind: str

@typing.type_check_only
class Objects(typing_extensions.TypedDict, total=False):
    items: _list[Object]
    kind: str
    nextPageToken: str
    prefixes: _list[str]

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    bindings: _list[dict[str, typing.Any]]
    etag: str
    kind: str
    resourceId: str
    version: int

@typing.type_check_only
class RewriteResponse(typing_extensions.TypedDict, total=False):
    done: bool
    kind: str
    objectSize: str
    resource: Object
    rewriteToken: str
    totalBytesRewritten: str

@typing.type_check_only
class ServiceAccount(typing_extensions.TypedDict, total=False):
    email_address: str
    kind: str

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    kind: str
    permissions: _list[str]



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class BloggerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class BlogUserInfosResource(googleapiclient.discovery.Resource):
        def get(
            self, *, userId: str, blogId: str, maxPosts: int = ..., **kwargs: typing.Any
        ) -> BlogUserInfoHttpRequest: ...

    @typing.type_check_only
    class BlogsResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            blogId: str,
            maxPosts: int = ...,
            view: typing_extensions.Literal[
                "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
            ] = ...,
            **kwargs: typing.Any
        ) -> BlogHttpRequest: ...
        def getByUrl(
            self,
            *,
            url: str,
            view: typing_extensions.Literal[
                "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
            ] = ...,
            **kwargs: typing.Any
        ) -> BlogHttpRequest: ...
        def listByUser(
            self,
            *,
            userId: str,
            fetchUserInfo: bool = ...,
            role: typing_extensions.Literal[
                "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
            ]
            | _list[
                typing_extensions.Literal[
                    "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
                ]
            ] = ...,
            status: typing_extensions.Literal["LIVE", "DELETED"]
            | _list[typing_extensions.Literal["LIVE", "DELETED"]] = ...,
            view: typing_extensions.Literal[
                "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
            ] = ...,
            **kwargs: typing.Any
        ) -> BlogListHttpRequest: ...

    @typing.type_check_only
    class CommentsResource(googleapiclient.discovery.Resource):
        def approve(
            self, *, blogId: str, postId: str, commentId: str, **kwargs: typing.Any
        ) -> CommentHttpRequest: ...
        def delete(
            self, *, blogId: str, postId: str, commentId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            blogId: str,
            postId: str,
            commentId: str,
            view: typing_extensions.Literal[
                "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
            ] = ...,
            **kwargs: typing.Any
        ) -> CommentHttpRequest: ...
        def list(
            self,
            *,
            blogId: str,
            postId: str,
            endDate: str = ...,
            fetchBodies: bool = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            startDate: str = ...,
            status: typing_extensions.Literal[
                "LIVE", "EMPTIED", "PENDING", "SPAM"
            ] = ...,
            view: typing_extensions.Literal[
                "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
            ] = ...,
            **kwargs: typing.Any
        ) -> CommentListHttpRequest: ...
        def list_next(
            self,
            previous_request: CommentListHttpRequest,
            previous_response: CommentList,
        ) -> CommentListHttpRequest | None: ...
        def listByBlog(
            self,
            *,
            blogId: str,
            endDate: str = ...,
            fetchBodies: bool = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            startDate: str = ...,
            status: typing_extensions.Literal["LIVE", "EMPTIED", "PENDING", "SPAM"]
            | _list[
                typing_extensions.Literal["LIVE", "EMPTIED", "PENDING", "SPAM"]
            ] = ...,
            **kwargs: typing.Any
        ) -> CommentListHttpRequest: ...
        def listByBlog_next(
            self,
            previous_request: CommentListHttpRequest,
            previous_response: CommentList,
        ) -> CommentListHttpRequest | None: ...
        def markAsSpam(
            self, *, blogId: str, postId: str, commentId: str, **kwargs: typing.Any
        ) -> CommentHttpRequest: ...
        def removeContent(
            self, *, blogId: str, postId: str, commentId: str, **kwargs: typing.Any
        ) -> CommentHttpRequest: ...

    @typing.type_check_only
    class PageViewsResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            blogId: str,
            range: typing_extensions.Literal["all", "30DAYS", "7DAYS"]
            | _list[typing_extensions.Literal["all", "30DAYS", "7DAYS"]] = ...,
            **kwargs: typing.Any
        ) -> PageviewsHttpRequest: ...

    @typing.type_check_only
    class PagesResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, blogId: str, pageId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            blogId: str,
            pageId: str,
            view: typing_extensions.Literal[
                "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
            ] = ...,
            **kwargs: typing.Any
        ) -> PageHttpRequest: ...
        def insert(
            self,
            *,
            blogId: str,
            body: Page = ...,
            isDraft: bool = ...,
            **kwargs: typing.Any
        ) -> PageHttpRequest: ...
        def list(
            self,
            *,
            blogId: str,
            fetchBodies: bool = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            status: typing_extensions.Literal["LIVE", "DRAFT", "SOFT_TRASHED"]
            | _list[typing_extensions.Literal["LIVE", "DRAFT", "SOFT_TRASHED"]] = ...,
            view: typing_extensions.Literal[
                "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
            ] = ...,
            **kwargs: typing.Any
        ) -> PageListHttpRequest: ...
        def list_next(
            self, previous_request: PageListHttpRequest, previous_response: PageList
        ) -> PageListHttpRequest | None: ...
        def patch(
            self,
            *,
            blogId: str,
            pageId: str,
            body: Page = ...,
            publish: bool = ...,
            revert: bool = ...,
            **kwargs: typing.Any
        ) -> PageHttpRequest: ...
        def publish(
            self, *, blogId: str, pageId: str, **kwargs: typing.Any
        ) -> PageHttpRequest: ...
        def revert(
            self, *, blogId: str, pageId: str, **kwargs: typing.Any
        ) -> PageHttpRequest: ...
        def update(
            self,
            *,
            blogId: str,
            pageId: str,
            body: Page = ...,
            publish: bool = ...,
            revert: bool = ...,
            **kwargs: typing.Any
        ) -> PageHttpRequest: ...

    @typing.type_check_only
    class PostUserInfosResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            userId: str,
            blogId: str,
            postId: str,
            maxComments: int = ...,
            **kwargs: typing.Any
        ) -> PostUserInfoHttpRequest: ...
        def list(
            self,
            *,
            userId: str,
            blogId: str,
            endDate: str = ...,
            fetchBodies: bool = ...,
            labels: str = ...,
            maxResults: int = ...,
            orderBy: typing_extensions.Literal[
                "ORDER_BY_UNSPECIFIED", "PUBLISHED", "UPDATED"
            ] = ...,
            pageToken: str = ...,
            startDate: str = ...,
            status: typing_extensions.Literal[
                "LIVE", "DRAFT", "SCHEDULED", "SOFT_TRASHED"
            ]
            | _list[
                typing_extensions.Literal["LIVE", "DRAFT", "SCHEDULED", "SOFT_TRASHED"]
            ] = ...,
            view: typing_extensions.Literal[
                "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
            ] = ...,
            **kwargs: typing.Any
        ) -> PostUserInfosListHttpRequest: ...
        def list_next(
            self,
            previous_request: PostUserInfosListHttpRequest,
            previous_response: PostUserInfosList,
        ) -> PostUserInfosListHttpRequest | None: ...

    @typing.type_check_only
    class PostsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, blogId: str, postId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            blogId: str,
            postId: str,
            fetchBody: bool = ...,
            fetchImages: bool = ...,
            maxComments: int = ...,
            view: typing_extensions.Literal[
                "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
            ] = ...,
            **kwargs: typing.Any
        ) -> PostHttpRequest: ...
        def getByPath(
            self,
            *,
            blogId: str,
            path: str,
            maxComments: int = ...,
            view: typing_extensions.Literal[
                "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
            ] = ...,
            **kwargs: typing.Any
        ) -> PostHttpRequest: ...
        def insert(
            self,
            *,
            blogId: str,
            body: Post = ...,
            fetchBody: bool = ...,
            fetchImages: bool = ...,
            isDraft: bool = ...,
            **kwargs: typing.Any
        ) -> PostHttpRequest: ...
        def list(
            self,
            *,
            blogId: str,
            endDate: str = ...,
            fetchBodies: bool = ...,
            fetchImages: bool = ...,
            labels: str = ...,
            maxResults: int = ...,
            orderBy: typing_extensions.Literal[
                "ORDER_BY_UNSPECIFIED", "PUBLISHED", "UPDATED"
            ] = ...,
            pageToken: str = ...,
            startDate: str = ...,
            status: typing_extensions.Literal[
                "LIVE", "DRAFT", "SCHEDULED", "SOFT_TRASHED"
            ]
            | _list[
                typing_extensions.Literal["LIVE", "DRAFT", "SCHEDULED", "SOFT_TRASHED"]
            ] = ...,
            view: typing_extensions.Literal[
                "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
            ] = ...,
            **kwargs: typing.Any
        ) -> PostListHttpRequest: ...
        def list_next(
            self, previous_request: PostListHttpRequest, previous_response: PostList
        ) -> PostListHttpRequest | None: ...
        def patch(
            self,
            *,
            blogId: str,
            postId: str,
            body: Post = ...,
            fetchBody: bool = ...,
            fetchImages: bool = ...,
            maxComments: int = ...,
            publish: bool = ...,
            revert: bool = ...,
            **kwargs: typing.Any
        ) -> PostHttpRequest: ...
        def publish(
            self,
            *,
            blogId: str,
            postId: str,
            publishDate: str = ...,
            **kwargs: typing.Any
        ) -> PostHttpRequest: ...
        def revert(
            self, *, blogId: str, postId: str, **kwargs: typing.Any
        ) -> PostHttpRequest: ...
        def search(
            self,
            *,
            blogId: str,
            q: str,
            fetchBodies: bool = ...,
            orderBy: typing_extensions.Literal[
                "ORDER_BY_UNSPECIFIED", "PUBLISHED", "UPDATED"
            ] = ...,
            **kwargs: typing.Any
        ) -> PostListHttpRequest: ...
        def update(
            self,
            *,
            blogId: str,
            postId: str,
            body: Post = ...,
            fetchBody: bool = ...,
            fetchImages: bool = ...,
            maxComments: int = ...,
            publish: bool = ...,
            revert: bool = ...,
            **kwargs: typing.Any
        ) -> PostHttpRequest: ...

    @typing.type_check_only
    class UsersResource(googleapiclient.discovery.Resource):
        def get(self, *, userId: str, **kwargs: typing.Any) -> UserHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def blogUserInfos(self) -> BlogUserInfosResource: ...
    def blogs(self) -> BlogsResource: ...
    def comments(self) -> CommentsResource: ...
    def pageViews(self) -> PageViewsResource: ...
    def pages(self) -> PagesResource: ...
    def postUserInfos(self) -> PostUserInfosResource: ...
    def posts(self) -> PostsResource: ...
    def users(self) -> UsersResource: ...

@typing.type_check_only
class BlogHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Blog: ...

@typing.type_check_only
class BlogListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BlogList: ...

@typing.type_check_only
class BlogUserInfoHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BlogUserInfo: ...

@typing.type_check_only
class CommentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Comment: ...

@typing.type_check_only
class CommentListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CommentList: ...

@typing.type_check_only
class PageHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Page: ...

@typing.type_check_only
class PageListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PageList: ...

@typing.type_check_only
class PageviewsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Pageviews: ...

@typing.type_check_only
class PostHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Post: ...

@typing.type_check_only
class PostListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PostList: ...

@typing.type_check_only
class PostUserInfoHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PostUserInfo: ...

@typing.type_check_only
class PostUserInfosListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PostUserInfosList: ...

@typing.type_check_only
class UserHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> User: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class PublishUrlNotificationResponse(typing_extensions.TypedDict, total=False):
    urlNotificationMetadata: UrlNotificationMetadata

@typing.type_check_only
class UrlNotification(typing_extensions.TypedDict, total=False):
    notifyTime: str
    type: typing_extensions.Literal[
        "URL_NOTIFICATION_TYPE_UNSPECIFIED", "URL_UPDATED", "URL_DELETED"
    ]
    url: str

@typing.type_check_only
class UrlNotificationMetadata(typing_extensions.TypedDict, total=False):
    latestRemove: UrlNotification
    latestUpdate: UrlNotification
    url: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class BigQueryDataTransferResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DataSourcesResource(googleapiclient.discovery.Resource):
            def checkValidCreds(
                self,
                *,
                name: str,
                body: CheckValidCredsRequest = ...,
                **kwargs: typing.Any
            ) -> CheckValidCredsResponseHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> DataSourceHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListDataSourcesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListDataSourcesResponseHttpRequest,
                previous_response: ListDataSourcesResponse,
            ) -> ListDataSourcesResponseHttpRequest | None: ...

        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DataSourcesResource(googleapiclient.discovery.Resource):
                def checkValidCreds(
                    self,
                    *,
                    name: str,
                    body: CheckValidCredsRequest = ...,
                    **kwargs: typing.Any
                ) -> CheckValidCredsResponseHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> DataSourceHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListDataSourcesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListDataSourcesResponseHttpRequest,
                    previous_response: ListDataSourcesResponse,
                ) -> ListDataSourcesResponseHttpRequest | None: ...

            @typing.type_check_only
            class TransferConfigsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class RunsResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class TransferLogsResource(googleapiclient.discovery.Resource):
                        def list(
                            self,
                            *,
                            parent: str,
                            messageTypes: typing_extensions.Literal[
                                "MESSAGE_SEVERITY_UNSPECIFIED",
                                "INFO",
                                "WARNING",
                                "ERROR",
                            ]
                            | _list[
                                typing_extensions.Literal[
                                    "MESSAGE_SEVERITY_UNSPECIFIED",
                                    "INFO",
                                    "WARNING",
                                    "ERROR",
                                ]
                            ] = ...,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> ListTransferLogsResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: ListTransferLogsResponseHttpRequest,
                            previous_response: ListTransferLogsResponse,
                        ) -> ListTransferLogsResponseHttpRequest | None: ...

                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> TransferRunHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        runAttempt: typing_extensions.Literal[
                            "RUN_ATTEMPT_UNSPECIFIED", "LATEST"
                        ] = ...,
                        states: typing_extensions.Literal[
                            "TRANSFER_STATE_UNSPECIFIED",
                            "PENDING",
                            "RUNNING",
                            "SUCCEEDED",
                            "FAILED",
                            "CANCELLED",
                        ]
                        | _list[
                            typing_extensions.Literal[
                                "TRANSFER_STATE_UNSPECIFIED",
                                "PENDING",
                                "RUNNING",
                                "SUCCEEDED",
                                "FAILED",
                                "CANCELLED",
                            ]
                        ] = ...,
                        **kwargs: typing.Any
                    ) -> ListTransferRunsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListTransferRunsResponseHttpRequest,
                        previous_response: ListTransferRunsResponse,
                    ) -> ListTransferRunsResponseHttpRequest | None: ...
                    def transferLogs(self) -> TransferLogsResource: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: TransferConfig = ...,
                    authorizationCode: str = ...,
                    serviceAccountName: str = ...,
                    versionInfo: str = ...,
                    **kwargs: typing.Any
                ) -> TransferConfigHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> TransferConfigHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    dataSourceIds: str | _list[str] = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListTransferConfigsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListTransferConfigsResponseHttpRequest,
                    previous_response: ListTransferConfigsResponse,
                ) -> ListTransferConfigsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: TransferConfig = ...,
                    authorizationCode: str = ...,
                    serviceAccountName: str = ...,
                    updateMask: str = ...,
                    versionInfo: str = ...,
                    **kwargs: typing.Any
                ) -> TransferConfigHttpRequest: ...
                def scheduleRuns(
                    self,
                    *,
                    parent: str,
                    body: ScheduleTransferRunsRequest = ...,
                    **kwargs: typing.Any
                ) -> ScheduleTransferRunsResponseHttpRequest: ...
                def startManualRuns(
                    self,
                    *,
                    parent: str,
                    body: StartManualTransferRunsRequest = ...,
                    **kwargs: typing.Any
                ) -> StartManualTransferRunsResponseHttpRequest: ...
                def runs(self) -> RunsResource: ...

            def enrollDataSources(
                self,
                *,
                name: str,
                body: EnrollDataSourcesRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...
            def dataSources(self) -> DataSourcesResource: ...
            def transferConfigs(self) -> TransferConfigsResource: ...

        @typing.type_check_only
        class TransferConfigsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class RunsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class TransferLogsResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        parent: str,
                        messageTypes: typing_extensions.Literal[
                            "MESSAGE_SEVERITY_UNSPECIFIED", "INFO", "WARNING", "ERROR"
                        ]
                        | _list[
                            typing_extensions.Literal[
                                "MESSAGE_SEVERITY_UNSPECIFIED",
                                "INFO",
                                "WARNING",
                                "ERROR",
                            ]
                        ] = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListTransferLogsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListTransferLogsResponseHttpRequest,
                        previous_response: ListTransferLogsResponse,
                    ) -> ListTransferLogsResponseHttpRequest | None: ...

                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> TransferRunHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    runAttempt: typing_extensions.Literal[
                        "RUN_ATTEMPT_UNSPECIFIED", "LATEST"
                    ] = ...,
                    states: typing_extensions.Literal[
                        "TRANSFER_STATE_UNSPECIFIED",
                        "PENDING",
                        "RUNNING",
                        "SUCCEEDED",
                        "FAILED",
                        "CANCELLED",
                    ]
                    | _list[
                        typing_extensions.Literal[
                            "TRANSFER_STATE_UNSPECIFIED",
                            "PENDING",
                            "RUNNING",
                            "SUCCEEDED",
                            "FAILED",
                            "CANCELLED",
                        ]
                    ] = ...,
                    **kwargs: typing.Any
                ) -> ListTransferRunsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListTransferRunsResponseHttpRequest,
                    previous_response: ListTransferRunsResponse,
                ) -> ListTransferRunsResponseHttpRequest | None: ...
                def transferLogs(self) -> TransferLogsResource: ...

            def create(
                self,
                *,
                parent: str,
                body: TransferConfig = ...,
                authorizationCode: str = ...,
                serviceAccountName: str = ...,
                versionInfo: str = ...,
                **kwargs: typing.Any
            ) -> TransferConfigHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> TransferConfigHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                dataSourceIds: str | _list[str] = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListTransferConfigsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListTransferConfigsResponseHttpRequest,
                previous_response: ListTransferConfigsResponse,
            ) -> ListTransferConfigsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: TransferConfig = ...,
                authorizationCode: str = ...,
                serviceAccountName: str = ...,
                updateMask: str = ...,
                versionInfo: str = ...,
                **kwargs: typing.Any
            ) -> TransferConfigHttpRequest: ...
            def scheduleRuns(
                self,
                *,
                parent: str,
                body: ScheduleTransferRunsRequest = ...,
                **kwargs: typing.Any
            ) -> ScheduleTransferRunsResponseHttpRequest: ...
            def startManualRuns(
                self,
                *,
                parent: str,
                body: StartManualTransferRunsRequest = ...,
                **kwargs: typing.Any
            ) -> StartManualTransferRunsResponseHttpRequest: ...
            def runs(self) -> RunsResource: ...

        def enrollDataSources(
            self,
            *,
            name: str,
            body: EnrollDataSourcesRequest = ...,
            **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def dataSources(self) -> DataSourcesResource: ...
        def locations(self) -> LocationsResource: ...
        def transferConfigs(self) -> TransferConfigsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class CheckValidCredsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CheckValidCredsResponse: ...

@typing.type_check_only
class DataSourceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DataSource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListDataSourcesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDataSourcesResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListTransferConfigsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTransferConfigsResponse: ...

@typing.type_check_only
class ListTransferLogsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTransferLogsResponse: ...

@typing.type_check_only
class ListTransferRunsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTransferRunsResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class ScheduleTransferRunsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ScheduleTransferRunsResponse: ...

@typing.type_check_only
class StartManualTransferRunsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> StartManualTransferRunsResponse: ...

@typing.type_check_only
class TransferConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TransferConfig: ...

@typing.type_check_only
class TransferRunHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TransferRun: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class SecretManagerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...

        @typing.type_check_only
        class SecretsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class VersionsResource(googleapiclient.discovery.Resource):
                def access(
                    self, *, name: str, **kwargs: typing.Any
                ) -> AccessSecretVersionResponseHttpRequest: ...
                def destroy(
                    self,
                    *,
                    name: str,
                    body: DestroySecretVersionRequest = ...,
                    **kwargs: typing.Any
                ) -> SecretVersionHttpRequest: ...
                def disable(
                    self,
                    *,
                    name: str,
                    body: DisableSecretVersionRequest = ...,
                    **kwargs: typing.Any
                ) -> SecretVersionHttpRequest: ...
                def enable(
                    self,
                    *,
                    name: str,
                    body: EnableSecretVersionRequest = ...,
                    **kwargs: typing.Any
                ) -> SecretVersionHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> SecretVersionHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListSecretVersionsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListSecretVersionsResponseHttpRequest,
                    previous_response: ListSecretVersionsResponse,
                ) -> ListSecretVersionsResponseHttpRequest | None: ...

            def addVersion(
                self,
                *,
                parent: str,
                body: AddSecretVersionRequest = ...,
                **kwargs: typing.Any
            ) -> SecretVersionHttpRequest: ...
            def create(
                self,
                *,
                parent: str,
                body: Secret = ...,
                secretId: str = ...,
                **kwargs: typing.Any
            ) -> SecretHttpRequest: ...
            def delete(
                self, *, name: str, etag: str = ..., **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> SecretHttpRequest: ...
            def getIamPolicy(
                self,
                *,
                resource: str,
                options_requestedPolicyVersion: int = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListSecretsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListSecretsResponseHttpRequest,
                previous_response: ListSecretsResponse,
            ) -> ListSecretsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: Secret = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> SecretHttpRequest: ...
            def setIamPolicy(
                self,
                *,
                resource: str,
                body: SetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> TestIamPermissionsResponseHttpRequest: ...
            def versions(self) -> VersionsResource: ...

        def locations(self) -> LocationsResource: ...
        def secrets(self) -> SecretsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class AccessSecretVersionResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccessSecretVersionResponse: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListSecretVersionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSecretVersionsResponse: ...

@typing.type_check_only
class ListSecretsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSecretsResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class SecretHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Secret: ...

@typing.type_check_only
class SecretVersionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SecretVersion: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class PlayableLocationsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class V3Resource(googleapiclient.discovery.Resource):
        def logImpressions(
            self,
            *,
            body: GoogleMapsPlayablelocationsV3LogImpressionsRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleMapsPlayablelocationsV3LogImpressionsResponseHttpRequest: ...
        def logPlayerReports(
            self,
            *,
            body: GoogleMapsPlayablelocationsV3LogPlayerReportsRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleMapsPlayablelocationsV3LogPlayerReportsResponseHttpRequest: ...
        def samplePlayableLocations(
            self,
            *,
            body: GoogleMapsPlayablelocationsV3SamplePlayableLocationsRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleMapsPlayablelocationsV3SamplePlayableLocationsResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def v3(self) -> V3Resource: ...

@typing.type_check_only
class GoogleMapsPlayablelocationsV3LogImpressionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleMapsPlayablelocationsV3LogImpressionsResponse: ...

@typing.type_check_only
class GoogleMapsPlayablelocationsV3LogPlayerReportsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleMapsPlayablelocationsV3LogPlayerReportsResponse: ...

@typing.type_check_only
class GoogleMapsPlayablelocationsV3SamplePlayableLocationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleMapsPlayablelocationsV3SamplePlayableLocationsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudCommercePartnerProcurementServiceResource(
    googleapiclient.discovery.Resource
):
    @typing.type_check_only
    class ProvidersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AccountsResource(googleapiclient.discovery.Resource):
            def approve(
                self,
                *,
                name: str,
                body: ApproveAccountRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> AccountHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListAccountsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListAccountsResponseHttpRequest,
                previous_response: ListAccountsResponse,
            ) -> ListAccountsResponseHttpRequest | None: ...
            def reject(
                self,
                *,
                name: str,
                body: RejectAccountRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def reset(
                self,
                *,
                name: str,
                body: ResetAccountRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...

        @typing.type_check_only
        class EntitlementsResource(googleapiclient.discovery.Resource):
            def approve(
                self,
                *,
                name: str,
                body: ApproveEntitlementRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def approvePlanChange(
                self,
                *,
                name: str,
                body: ApproveEntitlementPlanChangeRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> EntitlementHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListEntitlementsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListEntitlementsResponseHttpRequest,
                previous_response: ListEntitlementsResponse,
            ) -> ListEntitlementsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: Entitlement = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> EntitlementHttpRequest: ...
            def reject(
                self,
                *,
                name: str,
                body: RejectEntitlementRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def rejectPlanChange(
                self,
                *,
                name: str,
                body: RejectEntitlementPlanChangeRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def suspend(
                self,
                *,
                name: str,
                body: SuspendEntitlementRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...

        def accounts(self) -> AccountsResource: ...
        def entitlements(self) -> EntitlementsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def providers(self) -> ProvidersResource: ...

@typing.type_check_only
class AccountHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Account: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class EntitlementHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Entitlement: ...

@typing.type_check_only
class ListAccountsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAccountsResponse: ...

@typing.type_check_only
class ListEntitlementsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListEntitlementsResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AchievementConfiguration(typing_extensions.TypedDict, total=False):
    achievementType: typing_extensions.Literal[
        "ACHIEVEMENT_TYPE_UNSPECIFIED", "STANDARD", "INCREMENTAL"
    ]
    draft: AchievementConfigurationDetail
    id: str
    initialState: typing_extensions.Literal[
        "INITIAL_STATE_UNSPECIFIED", "HIDDEN", "REVEALED"
    ]
    kind: str
    published: AchievementConfigurationDetail
    stepsToUnlock: int
    token: str

@typing.type_check_only
class AchievementConfigurationDetail(typing_extensions.TypedDict, total=False):
    description: LocalizedStringBundle
    iconUrl: str
    kind: str
    name: LocalizedStringBundle
    pointValue: int
    sortRank: int

@typing.type_check_only
class AchievementConfigurationListResponse(typing_extensions.TypedDict, total=False):
    items: _list[AchievementConfiguration]
    kind: str
    nextPageToken: str

@typing.type_check_only
class GamesNumberAffixConfiguration(typing_extensions.TypedDict, total=False):
    few: LocalizedStringBundle
    many: LocalizedStringBundle
    one: LocalizedStringBundle
    other: LocalizedStringBundle
    two: LocalizedStringBundle
    zero: LocalizedStringBundle

@typing.type_check_only
class GamesNumberFormatConfiguration(typing_extensions.TypedDict, total=False):
    currencyCode: str
    numDecimalPlaces: int
    numberFormatType: typing_extensions.Literal[
        "NUMBER_FORMAT_TYPE_UNSPECIFIED", "NUMERIC", "TIME_DURATION", "CURRENCY"
    ]
    suffix: GamesNumberAffixConfiguration

@typing.type_check_only
class ImageConfiguration(typing_extensions.TypedDict, total=False):
    imageType: typing_extensions.Literal[
        "IMAGE_TYPE_UNSPECIFIED", "ACHIEVEMENT_ICON", "LEADERBOARD_ICON"
    ]
    kind: str
    resourceId: str
    url: str

@typing.type_check_only
class LeaderboardConfiguration(typing_extensions.TypedDict, total=False):
    draft: LeaderboardConfigurationDetail
    id: str
    kind: str
    published: LeaderboardConfigurationDetail
    scoreMax: str
    scoreMin: str
    scoreOrder: typing_extensions.Literal[
        "SCORE_ORDER_UNSPECIFIED", "LARGER_IS_BETTER", "SMALLER_IS_BETTER"
    ]
    token: str

@typing.type_check_only
class LeaderboardConfigurationDetail(typing_extensions.TypedDict, total=False):
    iconUrl: str
    kind: str
    name: LocalizedStringBundle
    scoreFormat: GamesNumberFormatConfiguration
    sortRank: int

@typing.type_check_only
class LeaderboardConfigurationListResponse(typing_extensions.TypedDict, total=False):
    items: _list[LeaderboardConfiguration]
    kind: str
    nextPageToken: str

@typing.type_check_only
class LocalizedString(typing_extensions.TypedDict, total=False):
    kind: str
    locale: str
    value: str

@typing.type_check_only
class LocalizedStringBundle(typing_extensions.TypedDict, total=False):
    kind: str
    translations: _list[LocalizedString]



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CustomSearchAPIResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class CseResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class SiterestrictResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                c2coff: str = ...,
                cr: str = ...,
                cx: str = ...,
                dateRestrict: str = ...,
                exactTerms: str = ...,
                excludeTerms: str = ...,
                fileType: str = ...,
                filter: str = ...,
                gl: str = ...,
                googlehost: str = ...,
                highRange: str = ...,
                hl: str = ...,
                hq: str = ...,
                imgColorType: typing_extensions.Literal[
                    "imgColorTypeUndefined", "mono", "gray", "color", "trans"
                ] = ...,
                imgDominantColor: typing_extensions.Literal[
                    "imgDominantColorUndefined",
                    "black",
                    "blue",
                    "brown",
                    "gray",
                    "green",
                    "orange",
                    "pink",
                    "purple",
                    "red",
                    "teal",
                    "white",
                    "yellow",
                ] = ...,
                imgSize: typing_extensions.Literal[
                    "imgSizeUndefined",
                    "HUGE",
                    "ICON",
                    "LARGE",
                    "MEDIUM",
                    "SMALL",
                    "XLARGE",
                    "XXLARGE",
                ] = ...,
                imgType: typing_extensions.Literal[
                    "imgTypeUndefined",
                    "clipart",
                    "face",
                    "lineart",
                    "stock",
                    "photo",
                    "animated",
                ] = ...,
                linkSite: str = ...,
                lowRange: str = ...,
                lr: str = ...,
                num: int = ...,
                orTerms: str = ...,
                q: str = ...,
                relatedSite: str = ...,
                rights: str = ...,
                safe: typing_extensions.Literal[
                    "safeUndefined", "active", "high", "medium", "off"
                ] = ...,
                searchType: typing_extensions.Literal[
                    "searchTypeUndefined", "image"
                ] = ...,
                siteSearch: str = ...,
                siteSearchFilter: typing_extensions.Literal[
                    "siteSearchFilterUndefined", "e", "i"
                ] = ...,
                sort: str = ...,
                start: int = ...,
                **kwargs: typing.Any
            ) -> SearchHttpRequest: ...

        def list(
            self,
            *,
            c2coff: str = ...,
            cr: str = ...,
            cx: str = ...,
            dateRestrict: str = ...,
            exactTerms: str = ...,
            excludeTerms: str = ...,
            fileType: str = ...,
            filter: str = ...,
            gl: str = ...,
            googlehost: str = ...,
            highRange: str = ...,
            hl: str = ...,
            hq: str = ...,
            imgColorType: typing_extensions.Literal[
                "imgColorTypeUndefined", "mono", "gray", "color", "trans"
            ] = ...,
            imgDominantColor: typing_extensions.Literal[
                "imgDominantColorUndefined",
                "black",
                "blue",
                "brown",
                "gray",
                "green",
                "orange",
                "pink",
                "purple",
                "red",
                "teal",
                "white",
                "yellow",
            ] = ...,
            imgSize: typing_extensions.Literal[
                "imgSizeUndefined",
                "HUGE",
                "ICON",
                "LARGE",
                "MEDIUM",
                "SMALL",
                "XLARGE",
                "XXLARGE",
            ] = ...,
            imgType: typing_extensions.Literal[
                "imgTypeUndefined",
                "clipart",
                "face",
                "lineart",
                "stock",
                "photo",
                "animated",
            ] = ...,
            linkSite: str = ...,
            lowRange: str = ...,
            lr: str = ...,
            num: int = ...,
            orTerms: str = ...,
            q: str = ...,
            relatedSite: str = ...,
            rights: str = ...,
            safe: typing_extensions.Literal[
                "safeUndefined", "active", "high", "medium", "off"
            ] = ...,
            searchType: typing_extensions.Literal["searchTypeUndefined", "image"] = ...,
            siteSearch: str = ...,
            siteSearchFilter: typing_extensions.Literal[
                "siteSearchFilterUndefined", "e", "i"
            ] = ...,
            sort: str = ...,
            start: int = ...,
            **kwargs: typing.Any
        ) -> SearchHttpRequest: ...
        def siterestrict(self) -> SiterestrictResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def cse(self) -> CseResource: ...

@typing.type_check_only
class SearchHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Search: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class VisionResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class FilesResource(googleapiclient.discovery.Resource):
        def annotate(
            self, *, body: BatchAnnotateFilesRequest = ..., **kwargs: typing.Any
        ) -> BatchAnnotateFilesResponseHttpRequest: ...
        def asyncBatchAnnotate(
            self, *, body: AsyncBatchAnnotateFilesRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...

    @typing.type_check_only
    class ImagesResource(googleapiclient.discovery.Resource):
        def annotate(
            self, *, body: BatchAnnotateImagesRequest = ..., **kwargs: typing.Any
        ) -> BatchAnnotateImagesResponseHttpRequest: ...
        def asyncBatchAnnotate(
            self, *, body: AsyncBatchAnnotateImagesRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...

    @typing.type_check_only
    class LocationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class OperationsResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        def operations(self) -> OperationsResource: ...

    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def cancel(
            self, *, name: str, body: CancelOperationRequest = ..., **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def delete(self, *, name: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...
        def list(
            self,
            *,
            name: str,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListOperationsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListOperationsResponseHttpRequest,
            previous_response: ListOperationsResponse,
        ) -> ListOperationsResponseHttpRequest | None: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class FilesResource(googleapiclient.discovery.Resource):
            def annotate(
                self,
                *,
                parent: str,
                body: BatchAnnotateFilesRequest = ...,
                **kwargs: typing.Any
            ) -> BatchAnnotateFilesResponseHttpRequest: ...
            def asyncBatchAnnotate(
                self,
                *,
                parent: str,
                body: AsyncBatchAnnotateFilesRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        @typing.type_check_only
        class ImagesResource(googleapiclient.discovery.Resource):
            def annotate(
                self,
                *,
                parent: str,
                body: BatchAnnotateImagesRequest = ...,
                **kwargs: typing.Any
            ) -> BatchAnnotateImagesResponseHttpRequest: ...
            def asyncBatchAnnotate(
                self,
                *,
                parent: str,
                body: AsyncBatchAnnotateImagesRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class FilesResource(googleapiclient.discovery.Resource):
                def annotate(
                    self,
                    *,
                    parent: str,
                    body: BatchAnnotateFilesRequest = ...,
                    **kwargs: typing.Any
                ) -> BatchAnnotateFilesResponseHttpRequest: ...
                def asyncBatchAnnotate(
                    self,
                    *,
                    parent: str,
                    body: AsyncBatchAnnotateFilesRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class ImagesResource(googleapiclient.discovery.Resource):
                def annotate(
                    self,
                    *,
                    parent: str,
                    body: BatchAnnotateImagesRequest = ...,
                    **kwargs: typing.Any
                ) -> BatchAnnotateImagesResponseHttpRequest: ...
                def asyncBatchAnnotate(
                    self,
                    *,
                    parent: str,
                    body: AsyncBatchAnnotateImagesRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class ProductSetsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class ProductsResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        name: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListProductsInProductSetResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListProductsInProductSetResponseHttpRequest,
                        previous_response: ListProductsInProductSetResponse,
                    ) -> ListProductsInProductSetResponseHttpRequest | None: ...

                def addProduct(
                    self,
                    *,
                    name: str,
                    body: AddProductToProductSetRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: ProductSet = ...,
                    productSetId: str = ...,
                    **kwargs: typing.Any
                ) -> ProductSetHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ProductSetHttpRequest: ...
                def import_(
                    self,
                    *,
                    parent: str,
                    body: ImportProductSetsRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListProductSetsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListProductSetsResponseHttpRequest,
                    previous_response: ListProductSetsResponse,
                ) -> ListProductSetsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: ProductSet = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> ProductSetHttpRequest: ...
                def removeProduct(
                    self,
                    *,
                    name: str,
                    body: RemoveProductFromProductSetRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def products(self) -> ProductsResource: ...

            @typing.type_check_only
            class ProductsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class ReferenceImagesResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: ReferenceImage = ...,
                        referenceImageId: str = ...,
                        **kwargs: typing.Any
                    ) -> ReferenceImageHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> ReferenceImageHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListReferenceImagesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListReferenceImagesResponseHttpRequest,
                        previous_response: ListReferenceImagesResponse,
                    ) -> ListReferenceImagesResponseHttpRequest | None: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: Product = ...,
                    productId: str = ...,
                    **kwargs: typing.Any
                ) -> ProductHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ProductHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListProductsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListProductsResponseHttpRequest,
                    previous_response: ListProductsResponse,
                ) -> ListProductsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Product = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> ProductHttpRequest: ...
                def purge(
                    self,
                    *,
                    parent: str,
                    body: PurgeProductsRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def referenceImages(self) -> ReferenceImagesResource: ...

            def files(self) -> FilesResource: ...
            def images(self) -> ImagesResource: ...
            def operations(self) -> OperationsResource: ...
            def productSets(self) -> ProductSetsResource: ...
            def products(self) -> ProductsResource: ...

        @typing.type_check_only
        class OperationsResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        def files(self) -> FilesResource: ...
        def images(self) -> ImagesResource: ...
        def locations(self) -> LocationsResource: ...
        def operations(self) -> OperationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def files(self) -> FilesResource: ...
    def images(self) -> ImagesResource: ...
    def locations(self) -> LocationsResource: ...
    def operations(self) -> OperationsResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class BatchAnnotateFilesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchAnnotateFilesResponse: ...

@typing.type_check_only
class BatchAnnotateImagesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchAnnotateImagesResponse: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListProductSetsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListProductSetsResponse: ...

@typing.type_check_only
class ListProductsInProductSetResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListProductsInProductSetResponse: ...

@typing.type_check_only
class ListProductsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListProductsResponse: ...

@typing.type_check_only
class ListReferenceImagesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListReferenceImagesResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class ProductHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Product: ...

@typing.type_check_only
class ProductSetHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ProductSet: ...

@typing.type_check_only
class ReferenceImageHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReferenceImage: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Asset(typing_extensions.TypedDict, total=False):
    authorName: str
    createTime: str
    description: str
    displayName: str
    formats: _list[Format]
    isCurated: bool
    license: typing_extensions.Literal[
        "UNKNOWN", "CREATIVE_COMMONS_BY", "ALL_RIGHTS_RESERVED"
    ]
    metadata: str
    name: str
    presentationParams: PresentationParams
    remixInfo: RemixInfo
    thumbnail: File
    updateTime: str
    visibility: typing_extensions.Literal[
        "VISIBILITY_UNSPECIFIED", "PRIVATE", "UNLISTED", "PUBLIC"
    ]

@typing.type_check_only
class AssetImportMessage(typing_extensions.TypedDict, total=False):
    code: typing_extensions.Literal[
        "CODE_UNSPECIFIED",
        "NO_IMPORTABLE_FILE",
        "EMPTY_MODEL",
        "OBJ_PARSE_ERROR",
        "EXPIRED",
        "IMAGE_ERROR",
        "EXTRA_FILES_WITH_ARCHIVE",
        "DEFAULT_MATERIALS",
        "FATAL_ERROR",
        "INVALID_ELEMENT_TYPE",
    ]
    filePath: str
    imageError: ImageError
    objParseError: ObjParseError

@typing.type_check_only
class File(typing_extensions.TypedDict, total=False):
    contentType: str
    relativePath: str
    url: str

@typing.type_check_only
class Format(typing_extensions.TypedDict, total=False):
    formatComplexity: FormatComplexity
    formatType: str
    resources: _list[File]
    root: File

@typing.type_check_only
class FormatComplexity(typing_extensions.TypedDict, total=False):
    lodHint: int
    triangleCount: str

@typing.type_check_only
class ImageError(typing_extensions.TypedDict, total=False):
    code: typing_extensions.Literal[
        "CODE_UNSPECIFIED", "INVALID_IMAGE", "IMAGE_TOO_BIG", "WRONG_IMAGE_TYPE"
    ]
    filePath: str

@typing.type_check_only
class ListAssetsResponse(typing_extensions.TypedDict, total=False):
    assets: _list[Asset]
    nextPageToken: str
    totalSize: int

@typing.type_check_only
class ListLikedAssetsResponse(typing_extensions.TypedDict, total=False):
    assets: _list[Asset]
    nextPageToken: str
    totalSize: int

@typing.type_check_only
class ListUserAssetsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    totalSize: int
    userAssets: _list[UserAsset]

@typing.type_check_only
class ObjParseError(typing_extensions.TypedDict, total=False):
    code: typing_extensions.Literal[
        "CODE_UNSPECIFIED",
        "INCONSISTENT_VERTEX_REFS",
        "INVALID_COMMAND",
        "INVALID_NUMBER",
        "INVALID_VERTEX_REF",
        "MISSING_GEOMETRIC_VERTEX",
        "MISSING_TOKEN",
        "TOO_FEW_DIMENSIONS",
        "TOO_FEW_VERTICES",
        "TOO_MANY_DIMENSIONS",
        "UNSUPPORTED_COMMAND",
        "UNUSED_TOKENS",
        "VERTEX_NOT_FOUND",
        "NUMBER_OUT_OF_RANGE",
        "INVALID_VALUE",
        "INVALID_TEXTURE_OPTION",
        "TOO_MANY_PROBLEMS",
        "MISSING_FILE_NAME",
        "FILE_NOT_FOUND",
        "UNKNOWN_MATERIAL",
        "NO_MATERIAL_DEFINED",
        "INVALID_SMOOTHING_GROUP",
        "MISSING_VERTEX_COLORS",
        "FILE_SUBSTITUTION",
        "LINE_TOO_LONG",
        "INVALID_FILE_PATH",
    ]
    endIndex: int
    filePath: str
    line: str
    lineNumber: int
    startIndex: int

@typing.type_check_only
class PresentationParams(typing_extensions.TypedDict, total=False):
    backgroundColor: str
    colorSpace: typing_extensions.Literal["UNKNOWN", "LINEAR", "GAMMA"]
    orientingRotation: Quaternion

@typing.type_check_only
class Quaternion(typing_extensions.TypedDict, total=False):
    w: float
    x: float
    y: float
    z: float

@typing.type_check_only
class RemixInfo(typing_extensions.TypedDict, total=False):
    sourceAsset: _list[str]

@typing.type_check_only
class StartAssetImportResponse(typing_extensions.TypedDict, total=False):
    assetId: str
    assetImportId: str
    assetImportMessages: _list[AssetImportMessage]
    publishUrl: str

@typing.type_check_only
class UserAsset(typing_extensions.TypedDict, total=False):
    asset: Asset



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class GamesManagementResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AchievementsResource(googleapiclient.discovery.Resource):
        def reset(
            self, *, achievementId: str, **kwargs: typing.Any
        ) -> AchievementResetResponseHttpRequest: ...
        def resetAll(
            self, **kwargs: typing.Any
        ) -> AchievementResetAllResponseHttpRequest: ...
        def resetAllForAllPlayers(
            self, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def resetForAllPlayers(
            self, *, achievementId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def resetMultipleForAllPlayers(
            self,
            *,
            body: AchievementResetMultipleForAllRequest = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class ApplicationsResource(googleapiclient.discovery.Resource):
        def listHidden(
            self,
            *,
            applicationId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> HiddenPlayerListHttpRequest: ...
        def listHidden_next(
            self,
            previous_request: HiddenPlayerListHttpRequest,
            previous_response: HiddenPlayerList,
        ) -> HiddenPlayerListHttpRequest | None: ...

    @typing.type_check_only
    class EventsResource(googleapiclient.discovery.Resource):
        def reset(
            self, *, eventId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def resetAll(
            self, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def resetAllForAllPlayers(
            self, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def resetForAllPlayers(
            self, *, eventId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def resetMultipleForAllPlayers(
            self, *, body: EventsResetMultipleForAllRequest = ..., **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class PlayersResource(googleapiclient.discovery.Resource):
        def hide(
            self, *, applicationId: str, playerId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def unhide(
            self, *, applicationId: str, playerId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class ScoresResource(googleapiclient.discovery.Resource):
        def reset(
            self, *, leaderboardId: str, **kwargs: typing.Any
        ) -> PlayerScoreResetResponseHttpRequest: ...
        def resetAll(
            self, **kwargs: typing.Any
        ) -> PlayerScoreResetAllResponseHttpRequest: ...
        def resetAllForAllPlayers(
            self, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def resetForAllPlayers(
            self, *, leaderboardId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def resetMultipleForAllPlayers(
            self, *, body: ScoresResetMultipleForAllRequest = ..., **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def achievements(self) -> AchievementsResource: ...
    def applications(self) -> ApplicationsResource: ...
    def events(self) -> EventsResource: ...
    def players(self) -> PlayersResource: ...
    def scores(self) -> ScoresResource: ...

@typing.type_check_only
class AchievementResetAllResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AchievementResetAllResponse: ...

@typing.type_check_only
class AchievementResetResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AchievementResetResponse: ...

@typing.type_check_only
class HiddenPlayerListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> HiddenPlayerList: ...

@typing.type_check_only
class PlayerScoreResetAllResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PlayerScoreResetAllResponse: ...

@typing.type_check_only
class PlayerScoreResetResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PlayerScoreResetResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Action(typing_extensions.TypedDict, total=False):
    inputParameters: _list[InputParameter]
    name: str
    resultMetadata: _list[ResultMetadata]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Entity(typing_extensions.TypedDict, total=False):
    fields: dict[str, typing.Any]
    name: str

@typing.type_check_only
class EntityType(typing_extensions.TypedDict, total=False):
    fields: _list[Field]
    name: str

@typing.type_check_only
class ExecuteActionRequest(typing_extensions.TypedDict, total=False):
    parameters: dict[str, typing.Any]

@typing.type_check_only
class ExecuteActionResponse(typing_extensions.TypedDict, total=False):
    results: _list[dict[str, typing.Any]]

@typing.type_check_only
class ExecuteSqlQueryRequest(typing_extensions.TypedDict, total=False):
    query: Query

@typing.type_check_only
class ExecuteSqlQueryResponse(typing_extensions.TypedDict, total=False):
    results: _list[dict[str, typing.Any]]

@typing.type_check_only
class Field(typing_extensions.TypedDict, total=False):
    additionalDetails: dict[str, typing.Any]
    dataType: typing_extensions.Literal[
        "DATA_TYPE_UNSPECIFIED",
        "INT",
        "SMALLINT",
        "DOUBLE",
        "DATE",
        "DATETIME",
        "TIME",
        "STRING",
        "LONG",
        "BOOLEAN",
        "DECIMAL",
        "UUID",
        "BLOB",
        "BIT",
        "TINYINT",
        "INTEGER",
        "BIGINT",
        "FLOAT",
        "REAL",
        "NUMERIC",
        "CHAR",
        "VARCHAR",
        "LONGVARCHAR",
        "TIMESTAMP",
        "NCHAR",
        "NVARCHAR",
        "LONGNVARCHAR",
        "NULL",
        "OTHER",
        "JAVA_OBJECT",
        "DISTINCT",
        "STRUCT",
        "ARRAY",
        "CLOB",
        "REF",
        "DATALINK",
        "ROWID",
        "BINARY",
        "VARBINARY",
        "LONGVARBINARY",
        "NCLOB",
        "SQLXML",
        "REF_CURSOR",
        "TIME_WITH_TIMEZONE",
        "TIMESTAMP_WITH_TIMEZONE",
    ]
    defaultValue: typing.Any
    description: str
    key: bool
    name: str
    nullable: bool
    reference: Reference

@typing.type_check_only
class InputParameter(typing_extensions.TypedDict, total=False):
    dataType: typing_extensions.Literal[
        "DATA_TYPE_UNSPECIFIED",
        "INT",
        "SMALLINT",
        "DOUBLE",
        "DATE",
        "DATETIME",
        "TIME",
        "STRING",
        "LONG",
        "BOOLEAN",
        "DECIMAL",
        "UUID",
        "BLOB",
        "BIT",
        "TINYINT",
        "INTEGER",
        "BIGINT",
        "FLOAT",
        "REAL",
        "NUMERIC",
        "CHAR",
        "VARCHAR",
        "LONGVARCHAR",
        "TIMESTAMP",
        "NCHAR",
        "NVARCHAR",
        "LONGNVARCHAR",
        "NULL",
        "OTHER",
        "JAVA_OBJECT",
        "DISTINCT",
        "STRUCT",
        "ARRAY",
        "CLOB",
        "REF",
        "DATALINK",
        "ROWID",
        "BINARY",
        "VARBINARY",
        "LONGVARBINARY",
        "NCLOB",
        "SQLXML",
        "REF_CURSOR",
        "TIME_WITH_TIMEZONE",
        "TIMESTAMP_WITH_TIMEZONE",
    ]
    defaultValue: typing.Any
    description: str
    name: str
    nullable: bool

@typing.type_check_only
class ListActionsResponse(typing_extensions.TypedDict, total=False):
    actions: _list[Action]
    nextPageToken: str
    unsupportedActionNames: _list[str]

@typing.type_check_only
class ListEntitiesResponse(typing_extensions.TypedDict, total=False):
    entities: _list[Entity]
    nextPageToken: str

@typing.type_check_only
class ListEntityTypesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    types: _list[EntityType]
    unsupportedTypeNames: _list[str]

@typing.type_check_only
class Query(typing_extensions.TypedDict, total=False):
    query: str

@typing.type_check_only
class Reference(typing_extensions.TypedDict, total=False):
    name: str
    type: str

@typing.type_check_only
class ResultMetadata(typing_extensions.TypedDict, total=False):
    dataType: typing_extensions.Literal[
        "DATA_TYPE_UNSPECIFIED",
        "INT",
        "SMALLINT",
        "DOUBLE",
        "DATE",
        "DATETIME",
        "TIME",
        "STRING",
        "LONG",
        "BOOLEAN",
        "DECIMAL",
        "UUID",
        "BLOB",
        "BIT",
        "TINYINT",
        "INTEGER",
        "BIGINT",
        "FLOAT",
        "REAL",
        "NUMERIC",
        "CHAR",
        "VARCHAR",
        "LONGVARCHAR",
        "TIMESTAMP",
        "NCHAR",
        "NVARCHAR",
        "LONGNVARCHAR",
        "NULL",
        "OTHER",
        "JAVA_OBJECT",
        "DISTINCT",
        "STRUCT",
        "ARRAY",
        "CLOB",
        "REF",
        "DATALINK",
        "ROWID",
        "BINARY",
        "VARBINARY",
        "LONGVARBINARY",
        "NCLOB",
        "SQLXML",
        "REF_CURSOR",
        "TIME_WITH_TIMEZONE",
        "TIMESTAMP_WITH_TIMEZONE",
    ]
    description: str
    name: str

@typing.type_check_only
class UpdateEntitiesWithConditionsResponse(typing_extensions.TypedDict, total=False):
    response: dict[str, typing.Any]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AnalyzeIamPolicyLongrunningMetadata(typing_extensions.TypedDict, total=False):
    createTime: str

@typing.type_check_only
class AnalyzeIamPolicyLongrunningResponse(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class GoogleCloudAssetV1p7beta1Asset(typing_extensions.TypedDict, total=False):
    accessLevel: GoogleIdentityAccesscontextmanagerV1AccessLevel
    accessPolicy: GoogleIdentityAccesscontextmanagerV1AccessPolicy
    ancestors: _list[str]
    assetType: str
    iamPolicy: Policy
    name: str
    orgPolicy: _list[GoogleCloudOrgpolicyV1Policy]
    relatedAssets: GoogleCloudAssetV1p7beta1RelatedAssets
    resource: GoogleCloudAssetV1p7beta1Resource
    servicePerimeter: GoogleIdentityAccesscontextmanagerV1ServicePerimeter
    updateTime: str

@typing.type_check_only
class GoogleCloudAssetV1p7beta1BigQueryDestination(
    typing_extensions.TypedDict, total=False
):
    dataset: str
    force: bool
    partitionSpec: GoogleCloudAssetV1p7beta1PartitionSpec
    separateTablesPerAssetType: bool
    table: str

@typing.type_check_only
class GoogleCloudAssetV1p7beta1ExportAssetsRequest(
    typing_extensions.TypedDict, total=False
):
    assetTypes: _list[str]
    contentType: typing_extensions.Literal[
        "CONTENT_TYPE_UNSPECIFIED",
        "RESOURCE",
        "IAM_POLICY",
        "ORG_POLICY",
        "ACCESS_POLICY",
        "RELATIONSHIP",
    ]
    outputConfig: GoogleCloudAssetV1p7beta1OutputConfig
    readTime: str
    relationshipTypes: _list[str]

@typing.type_check_only
class GoogleCloudAssetV1p7beta1GcsDestination(typing_extensions.TypedDict, total=False):
    uri: str
    uriPrefix: str

@typing.type_check_only
class GoogleCloudAssetV1p7beta1OutputConfig(typing_extensions.TypedDict, total=False):
    bigqueryDestination: GoogleCloudAssetV1p7beta1BigQueryDestination
    gcsDestination: GoogleCloudAssetV1p7beta1GcsDestination

@typing.type_check_only
class GoogleCloudAssetV1p7beta1PartitionSpec(typing_extensions.TypedDict, total=False):
    partitionKey: typing_extensions.Literal[
        "PARTITION_KEY_UNSPECIFIED", "READ_TIME", "REQUEST_TIME"
    ]

@typing.type_check_only
class GoogleCloudAssetV1p7beta1RelatedAsset(typing_extensions.TypedDict, total=False):
    ancestors: _list[str]
    asset: str
    assetType: str

@typing.type_check_only
class GoogleCloudAssetV1p7beta1RelatedAssets(typing_extensions.TypedDict, total=False):
    assets: _list[GoogleCloudAssetV1p7beta1RelatedAsset]
    relationshipAttributes: GoogleCloudAssetV1p7beta1RelationshipAttributes

@typing.type_check_only
class GoogleCloudAssetV1p7beta1RelationshipAttributes(
    typing_extensions.TypedDict, total=False
):
    action: str
    sourceResourceType: str
    targetResourceType: str
    type: str

@typing.type_check_only
class GoogleCloudAssetV1p7beta1Resource(typing_extensions.TypedDict, total=False):
    data: dict[str, typing.Any]
    discoveryDocumentUri: str
    discoveryName: str
    location: str
    parent: str
    resourceUrl: str
    version: str

@typing.type_check_only
class GoogleCloudOrgpolicyV1BooleanPolicy(typing_extensions.TypedDict, total=False):
    enforced: bool

@typing.type_check_only
class GoogleCloudOrgpolicyV1ListPolicy(typing_extensions.TypedDict, total=False):
    allValues: typing_extensions.Literal["ALL_VALUES_UNSPECIFIED", "ALLOW", "DENY"]
    allowedValues: _list[str]
    deniedValues: _list[str]
    inheritFromParent: bool
    suggestedValue: str

@typing.type_check_only
class GoogleCloudOrgpolicyV1Policy(typing_extensions.TypedDict, total=False):
    booleanPolicy: GoogleCloudOrgpolicyV1BooleanPolicy
    constraint: str
    etag: str
    listPolicy: GoogleCloudOrgpolicyV1ListPolicy
    restoreDefault: GoogleCloudOrgpolicyV1RestoreDefault
    updateTime: str
    version: int

@typing.type_check_only
class GoogleCloudOrgpolicyV1RestoreDefault(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1AccessLevel(
    typing_extensions.TypedDict, total=False
):
    basic: GoogleIdentityAccesscontextmanagerV1BasicLevel
    custom: GoogleIdentityAccesscontextmanagerV1CustomLevel
    description: str
    name: str
    title: str

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1AccessPolicy(
    typing_extensions.TypedDict, total=False
):
    etag: str
    name: str
    parent: str
    scopes: _list[str]
    title: str

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1ApiOperation(
    typing_extensions.TypedDict, total=False
):
    methodSelectors: _list[GoogleIdentityAccesscontextmanagerV1MethodSelector]
    serviceName: str

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1BasicLevel(
    typing_extensions.TypedDict, total=False
):
    combiningFunction: typing_extensions.Literal["AND", "OR"]
    conditions: _list[GoogleIdentityAccesscontextmanagerV1Condition]

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1Condition(
    typing_extensions.TypedDict, total=False
):
    devicePolicy: GoogleIdentityAccesscontextmanagerV1DevicePolicy
    ipSubnetworks: _list[str]
    members: _list[str]
    negate: bool
    regions: _list[str]
    requiredAccessLevels: _list[str]

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1CustomLevel(
    typing_extensions.TypedDict, total=False
):
    expr: Expr

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1DevicePolicy(
    typing_extensions.TypedDict, total=False
):
    allowedDeviceManagementLevels: _list[str]
    allowedEncryptionStatuses: _list[str]
    osConstraints: _list[GoogleIdentityAccesscontextmanagerV1OsConstraint]
    requireAdminApproval: bool
    requireCorpOwned: bool
    requireScreenlock: bool

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1EgressFrom(
    typing_extensions.TypedDict, total=False
):
    identities: _list[str]
    identityType: typing_extensions.Literal[
        "IDENTITY_TYPE_UNSPECIFIED",
        "ANY_IDENTITY",
        "ANY_USER_ACCOUNT",
        "ANY_SERVICE_ACCOUNT",
    ]

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1EgressPolicy(
    typing_extensions.TypedDict, total=False
):
    egressFrom: GoogleIdentityAccesscontextmanagerV1EgressFrom
    egressTo: GoogleIdentityAccesscontextmanagerV1EgressTo

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1EgressTo(
    typing_extensions.TypedDict, total=False
):
    externalResources: _list[str]
    operations: _list[GoogleIdentityAccesscontextmanagerV1ApiOperation]
    resources: _list[str]

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1IngressFrom(
    typing_extensions.TypedDict, total=False
):
    identities: _list[str]
    identityType: typing_extensions.Literal[
        "IDENTITY_TYPE_UNSPECIFIED",
        "ANY_IDENTITY",
        "ANY_USER_ACCOUNT",
        "ANY_SERVICE_ACCOUNT",
    ]
    sources: _list[GoogleIdentityAccesscontextmanagerV1IngressSource]

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1IngressPolicy(
    typing_extensions.TypedDict, total=False
):
    ingressFrom: GoogleIdentityAccesscontextmanagerV1IngressFrom
    ingressTo: GoogleIdentityAccesscontextmanagerV1IngressTo

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1IngressSource(
    typing_extensions.TypedDict, total=False
):
    accessLevel: str
    resource: str

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1IngressTo(
    typing_extensions.TypedDict, total=False
):
    operations: _list[GoogleIdentityAccesscontextmanagerV1ApiOperation]
    resources: _list[str]

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1MethodSelector(
    typing_extensions.TypedDict, total=False
):
    method: str
    permission: str

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1OsConstraint(
    typing_extensions.TypedDict, total=False
):
    minimumVersion: str
    osType: typing_extensions.Literal[
        "OS_UNSPECIFIED",
        "DESKTOP_MAC",
        "DESKTOP_WINDOWS",
        "DESKTOP_LINUX",
        "DESKTOP_CHROME_OS",
        "ANDROID",
        "IOS",
    ]
    requireVerifiedChromeOs: bool

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1ServicePerimeter(
    typing_extensions.TypedDict, total=False
):
    description: str
    name: str
    perimeterType: typing_extensions.Literal[
        "PERIMETER_TYPE_REGULAR", "PERIMETER_TYPE_BRIDGE"
    ]
    spec: GoogleIdentityAccesscontextmanagerV1ServicePerimeterConfig
    status: GoogleIdentityAccesscontextmanagerV1ServicePerimeterConfig
    title: str
    useExplicitDryRunSpec: bool

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1ServicePerimeterConfig(
    typing_extensions.TypedDict, total=False
):
    accessLevels: _list[str]
    egressPolicies: _list[GoogleIdentityAccesscontextmanagerV1EgressPolicy]
    ingressPolicies: _list[GoogleIdentityAccesscontextmanagerV1IngressPolicy]
    resources: _list[str]
    restrictedServices: _list[str]
    vpcAccessibleServices: GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices

@typing.type_check_only
class GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices(
    typing_extensions.TypedDict, total=False
):
    allowedServices: _list[str]
    enableRestriction: bool

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str
